@@ -21,6 +21,7 @@ from tempfile import mkdtemp
 import osgeo.gdal as gdal
 import ogr, osr
 import numpy as np
+from shapely.geometry import box
 
 KEEP_FILENAME = ".tondor_keep"
 
@@ -369,14 +370,28 @@ def copy_singlefile_from_archive(scrfile_path, dstfile_path):
 
 def read_raster_info(raster_filepath):
     ds = gdal.Open(str(raster_filepath))
-    xmin, pixel_width, _, ymax, _, yres = ds.GetGeoTransform()
+
+    gt = ds.GetGeoTransform()
+    ulx_raster = gt[0]
+    uly_raster = gt[3]
+    lrx_raster = gt[0] + gt[1] * ds.RasterXSize + gt[2] * ds.RasterYSize
+    lry_raster = gt[3] + gt[4] * ds.RasterXSize + gt[5] * ds.RasterYSize
+    imagery_extent_box = box(lrx_raster, uly_raster, ulx_raster, lry_raster)
+    ds = None
+
+    xmin = gt[0]
+    ymax = gt[3]
+    pixel_width = gt[1]
+    yres = gt[5]
+
     projection = ds.GetProjection()
     datatype = ds.GetRasterBand(1).DataType
     n_bands = ds.RasterCount
     epsg = ds.GetSpatialRef().GetAuthorityCode(None)
-    return (xmin, ymax, ds.RasterXSize, ds.RasterYSize, pixel_width, projection, epsg, datatype, n_bands)
 
-def reproject_multibandraster(composite_filepath, warped_filepath, target_epsg, pixel_size, xmin, xmax, ymin, ymax, work_dir, method ='bilinear'):
+    return (xmin, ymax, ds.RasterXSize, ds.RasterYSize, pixel_width, projection, epsg, datatype, n_bands, imagery_extent_box)
+
+def reproject_multibandraster_toextent(composite_filepath, warped_filepath, target_epsg, pixel_size, xmin, xmax, ymin, ymax, work_dir, method ='bilinear'):
 
     cmd = ["gdalwarp",
            "-t_srs", "EPSG:{}".format(target_epsg),
@@ -389,6 +404,20 @@ def reproject_multibandraster(composite_filepath, warped_filepath, target_epsg,
            ]
     run_subprocess(cmd, work_dir)
 
+
+def reproject_multibandraster(composite_filepath, warped_filepath, target_epsg, pixel_size, work_dir, method ='bilinear'):
+
+    cmd = ["gdalwarp",
+           "-t_srs", "EPSG:{}".format(target_epsg),
+           "-tr", str(pixel_size), str(pixel_size),
+           "-r", method,
+           "-co", "COMPRESS=DEFLATE",
+           str(composite_filepath),
+           str(warped_filepath)
+           ]
+    run_subprocess(cmd, work_dir)
+
+
 #################################################################################################
 #################################################################################################
 def locate_optcomposites(archive_roots, year, sitecode, training_selection, site_selection):
